@@ -18,6 +18,8 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import unicode_literals
 
+import argparse
+
 from googlecloudsdk.calliope import arg_parsers
 from googlecloudsdk.calliope import base
 
@@ -65,6 +67,23 @@ def AddDescriptionArgToParser(parser):
             "Must not exceed 256 characters."))
 
 
+def AddAllowedValuesRegexArgToParser(parser: argparse.ArgumentParser) -> None:
+  """Adds argument for the Regex of allowed TagValues under a TagKey.
+
+  Args:
+    parser: ArgumentInterceptor, An argparse parser.
+  """
+  parser.add_argument(
+      "--allowed-values-regex",
+      metavar="ALLOWED_VALUES_REGEX",
+      type=str,
+      help=(
+          "User-assigned regex of allowed short names of TagValues under a"
+          " TagKey."
+      ),
+  )
+
+
 def AddPurposeArgToParser(parser):
   """Adds argument for the TagKey's purpose to the parser.
 
